summaryrefslogtreecommitdiff
path: root/svx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-08-22 11:19:52 +0200
committerNoel Grandin <noel@peralex.com>2016-08-23 09:54:16 +0200
commite0b61fdd35462ff679743dff1203fb5dd50e86a4 (patch)
tree46720d942ff6c656da2b79204294469510591d69 /svx
parentba263e124ce263c3c893542062d9c473f5aae589 (diff)
convert SdrIterMode to scoped enum
Change-Id: Iaa4631039e6b96627d8e547f21136f107e157d8a
Diffstat (limited to 'svx')
-rw-r--r--svx/source/customshapes/EnhancedCustomShape3d.cxx2
-rw-r--r--svx/source/customshapes/EnhancedCustomShapeEngine.cxx2
-rw-r--r--svx/source/customshapes/EnhancedCustomShapeFontWork.cxx2
-rw-r--r--svx/source/engine3d/helperhittest3d.cxx2
-rw-r--r--svx/source/engine3d/scene3d.cxx4
-rw-r--r--svx/source/engine3d/view3d.cxx12
-rw-r--r--svx/source/form/fmvwimp.cxx2
-rw-r--r--svx/source/sdr/properties/e3dsceneproperties.cxx2
-rw-r--r--svx/source/sdr/properties/itemsettools.cxx2
-rw-r--r--svx/source/sdr/properties/properties.cxx2
-rw-r--r--svx/source/svdraw/svdedtv1.cxx6
-rw-r--r--svx/source/svdraw/svdedtv2.cxx16
-rw-r--r--svx/source/svdraw/svdfmtf.cxx4
-rw-r--r--svx/source/svdraw/svditer.cxx4
-rw-r--r--svx/source/svdraw/svdpage.cxx4
-rw-r--r--svx/source/svdraw/svdsnpv.cxx4
-rw-r--r--svx/source/unodraw/unoshap3.cxx2
17 files changed, 36 insertions, 36 deletions
diff --git a/svx/source/customshapes/EnhancedCustomShape3d.cxx b/svx/source/customshapes/EnhancedCustomShape3d.cxx
index 10c372d7e48d..94e8eff10db8 100644
--- a/svx/source/customshapes/EnhancedCustomShape3d.cxx
+++ b/svx/source/customshapes/EnhancedCustomShape3d.cxx
@@ -368,7 +368,7 @@ SdrObject* EnhancedCustomShape3d::Create3DObject( const SdrObject* pShape2d, con
}
Rectangle aBoundRect2d;
- SdrObjListIter aIter( *pShape2d, IM_DEEPNOGROUPS );
+ SdrObjListIter aIter( *pShape2d, SdrIterMode::DeepNoGroups );
const bool bMultipleSubObjects(aIter.Count() > 1);
while( aIter.IsMore() )
diff --git a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
index 692e08ec1ce9..15ce39efb7d7 100644
--- a/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeEngine.cxx
@@ -433,7 +433,7 @@ drawing::PolyPolygonBezierCoords SAL_CALL EnhancedCustomShapeEngine::getLineGeom
}
basegfx::B2DPolyPolygon aPolyPolygon;
- SdrObjListIter aIter( *pObj, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pObj, SdrIterMode::DeepWithGroups );
while ( aIter.IsMore() )
{
diff --git a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
index 89f1d6f2413a..989d329cdd7e 100644
--- a/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
+++ b/svx/source/customshapes/EnhancedCustomShapeFontWork.cxx
@@ -510,7 +510,7 @@ basegfx::B2DPolyPolygon GetOutlinesFromShape2d( const SdrObject* pShape2d )
{
basegfx::B2DPolyPolygon aOutlines2d;
- SdrObjListIter aObjListIter( *pShape2d, IM_DEEPWITHGROUPS );
+ SdrObjListIter aObjListIter( *pShape2d, SdrIterMode::DeepWithGroups );
while( aObjListIter.IsMore() )
{
SdrObject* pPartObj = aObjListIter.Next();
diff --git a/svx/source/engine3d/helperhittest3d.cxx b/svx/source/engine3d/helperhittest3d.cxx
index c9b47b3394d2..eb0226981d07 100644
--- a/svx/source/engine3d/helperhittest3d.cxx
+++ b/svx/source/engine3d/helperhittest3d.cxx
@@ -175,7 +175,7 @@ void getAllHit3DObjectsSortedFrontToBack(
// check if test point is inside scene's area at all
if(aRelativePoint.getX() >= 0.0 && aRelativePoint.getX() <= 1.0 && aRelativePoint.getY() >= 0.0 && aRelativePoint.getY() <= 1.0)
{
- SdrObjListIter aIterator(*pList, IM_DEEPNOGROUPS);
+ SdrObjListIter aIterator(*pList, SdrIterMode::DeepNoGroups);
::std::vector< ImplPairDephAndObject > aDepthAndObjectResults;
const uno::Sequence< beans::PropertyValue > aEmptyParameters;
drawinglayer::geometry::ViewInformation3D aViewInfo3D(aEmptyParameters);
diff --git a/svx/source/engine3d/scene3d.cxx b/svx/source/engine3d/scene3d.cxx
index b93ca3f01650..da2e7fb0a3d4 100644
--- a/svx/source/engine3d/scene3d.cxx
+++ b/svx/source/engine3d/scene3d.cxx
@@ -474,7 +474,7 @@ void E3dScene::RebuildLists()
// first delete
SdrLayerID nCurrLayerID = GetLayer();
- SdrObjListIter a3DIterator(maSubList, IM_FLAT);
+ SdrObjListIter a3DIterator(maSubList, SdrIterMode::Flat);
// then examine all the objects in the scene
while ( a3DIterator.IsMore() )
@@ -651,7 +651,7 @@ void E3dScene::RecalcSnapRect()
bool E3dScene::IsBreakObjPossible()
{
// Break scene, if all members are able to break
- SdrObjListIter a3DIterator(maSubList, IM_DEEPWITHGROUPS);
+ SdrObjListIter a3DIterator(maSubList, SdrIterMode::DeepWithGroups);
while ( a3DIterator.IsMore() )
{
diff --git a/svx/source/engine3d/view3d.cxx b/svx/source/engine3d/view3d.cxx
index d6e001590c73..3847c61db547 100644
--- a/svx/source/engine3d/view3d.cxx
+++ b/svx/source/engine3d/view3d.cxx
@@ -636,7 +636,7 @@ void E3dView::ImpIsConvertTo3DPossible(SdrObject* pObj, bool& rAny3D,
{
if(pObj->IsGroupObject())
{
- SdrObjListIter aIter(*pObj, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
SdrObject* pNewObj = aIter.Next();
@@ -770,7 +770,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// change text color attribute for not so dark colors
if(pObj->IsGroupObject())
{
- SdrObjListIter aIter(*pObj, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -788,7 +788,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// change text color attribute for not so dark colors
if(pNewObj1->IsGroupObject())
{
- SdrObjListIter aIter(*pNewObj1, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pNewObj1, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -806,7 +806,7 @@ void E3dView::ImpCreate3DObject(E3dScene* pScene, SdrObject* pObj, bool bExtrude
// add all to flat scene
if(pNewObj2->IsGroupObject())
{
- SdrObjListIter aIter(*pNewObj2, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pNewObj2, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
SdrObject* pGroupMember = aIter.Next();
@@ -1044,7 +1044,7 @@ void E3dView::DoDepthArrange(E3dScene* pScene, double fDepth)
if(pScene && pScene->GetSubList() && pScene->GetSubList()->GetObjCount() > 1)
{
SdrObjList* pSubList = pScene->GetSubList();
- SdrObjListIter aIter(*pSubList, IM_FLAT);
+ SdrObjListIter aIter(*pSubList, SdrIterMode::Flat);
E3dDepthLayer* pBaseLayer = nullptr;
E3dDepthLayer* pLayer = nullptr;
sal_Int32 nNumLayers = 0;
@@ -1585,7 +1585,7 @@ void E3dView::BreakSingle3DObj(E3dObject* pObj)
if(dynamic_cast< const E3dScene* >(pObj) != nullptr)
{
SdrObjList* pSubList = pObj->GetSubList();
- SdrObjListIter aIter(*pSubList, IM_FLAT);
+ SdrObjListIter aIter(*pSubList, SdrIterMode::Flat);
while(aIter.IsMore())
{
diff --git a/svx/source/form/fmvwimp.cxx b/svx/source/form/fmvwimp.cxx
index f330a6408451..d572c3f333a0 100644
--- a/svx/source/form/fmvwimp.cxx
+++ b/svx/source/form/fmvwimp.cxx
@@ -888,7 +888,7 @@ namespace
{
Reference< XInterface > xNormalizedForm( _rxForm, UNO_QUERY_THROW );
- SdrObjListIter aSdrObjectLoop( _rPage, IM_DEEPNOGROUPS );
+ SdrObjListIter aSdrObjectLoop( _rPage, SdrIterMode::DeepNoGroups );
while ( aSdrObjectLoop.IsMore() )
{
FmFormObj* pFormObject = FmFormObj::GetFormObject( aSdrObjectLoop.Next() );
diff --git a/svx/source/sdr/properties/e3dsceneproperties.cxx b/svx/source/sdr/properties/e3dsceneproperties.cxx
index 44c28b5bc8b1..8c402b3f598d 100644
--- a/svx/source/sdr/properties/e3dsceneproperties.cxx
+++ b/svx/source/sdr/properties/e3dsceneproperties.cxx
@@ -286,7 +286,7 @@ namespace sdr
if(pSubList && rObj.GetScene() == &rObj)
{
- SdrObjListIter a3DIterator(*pSubList, IM_DEEPWITHGROUPS);
+ SdrObjListIter a3DIterator(*pSubList, SdrIterMode::DeepWithGroups);
while(a3DIterator.IsMore())
{
diff --git a/svx/source/sdr/properties/itemsettools.cxx b/svx/source/sdr/properties/itemsettools.cxx
index bef396c1ec41..64c70eb47307 100644
--- a/svx/source/sdr/properties/itemsettools.cxx
+++ b/svx/source/sdr/properties/itemsettools.cxx
@@ -38,7 +38,7 @@ namespace sdr
{
if(dynamic_cast<const SdrObjGroup*>( &rObj ) != nullptr)
{
- SdrObjListIter aIter(static_cast<const SdrObjGroup&>(rObj), IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(static_cast<const SdrObjGroup&>(rObj), SdrIterMode::DeepNoGroups);
mpData = new RectangleVector;
DBG_ASSERT(mpData, "ItemChangeBroadcaster: No memory (!)");
static_cast<RectangleVector*>(mpData)->reserve(aIter.Count());
diff --git a/svx/source/sdr/properties/properties.cxx b/svx/source/sdr/properties/properties.cxx
index a78aea4bcc0a..1cda9c4328d6 100644
--- a/svx/source/sdr/properties/properties.cxx
+++ b/svx/source/sdr/properties/properties.cxx
@@ -142,7 +142,7 @@ namespace sdr
// invalidate all new rectangles
if(dynamic_cast<const SdrObjGroup*>( &GetSdrObject() ) != nullptr)
{
- SdrObjListIter aIter(static_cast<SdrObjGroup&>(GetSdrObject()), IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(static_cast<SdrObjGroup&>(GetSdrObject()), SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
diff --git a/svx/source/svdraw/svdedtv1.cxx b/svx/source/svdraw/svdedtv1.cxx
index 68074a848e44..3573520eccb5 100644
--- a/svx/source/svdraw/svdedtv1.cxx
+++ b/svx/source/svdraw/svdedtv1.cxx
@@ -147,7 +147,7 @@ std::vector< SdrUndoAction* > SdrEditView::CreateConnectorUndo( SdrObject& rO )
const SdrPage* pPage = rO.GetPage();
if ( pPage )
{
- SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+ SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
while( aIter.IsMore() )
{
SdrObject* pPartObj = aIter.Next();
@@ -609,7 +609,7 @@ void SdrEditView::CrookMarkedObj(const Point& rRef, const Point& rRad, SdrCrookM
if (bNoContortion || pOL==nullptr) {
ImpCrookObj(pO,rRef,rRad,eMode,bVertical,bNoContortion,bRotate,aMarkRect);
} else {
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
SdrObject* pO1=aIter.Next();
ImpCrookObj(pO1,rRef,rRad,eMode,bVertical,bNoContortion,bRotate,aMarkRect);
@@ -684,7 +684,7 @@ void SdrEditView::DistortMarkedObj(const Rectangle& rRef, const XPolygon& rDisto
if (bNoContortion || pOL==nullptr) {
ImpDistortObj(pO,aRefRect,rDistortedRect,bNoContortion);
} else {
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
SdrObject* pO1=aIter.Next();
ImpDistortObj(pO1,aRefRect,rDistortedRect,bNoContortion);
diff --git a/svx/source/svdraw/svdedtv2.cxx b/svx/source/svdraw/svdedtv2.cxx
index 7cf36ae97b76..fbaf03e697a3 100644
--- a/svx/source/svdraw/svdedtv2.cxx
+++ b/svx/source/svdraw/svdedtv2.cxx
@@ -541,7 +541,7 @@ void SdrEditView::ImpCopyAttributes(const SdrObject* pSource, SdrObject* pDest)
if (pSource!=nullptr) {
SdrObjList* pOL=pSource->GetSubList();
if (pOL!=nullptr && !pSource->Is3DObj()) { // get first non-group object from group
- SdrObjListIter aIter(*pOL,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL,SdrIterMode::DeepNoGroups);
pSource=aIter.Next();
}
}
@@ -588,7 +588,7 @@ bool SdrEditView::ImpCanConvertForCombine(const SdrObject* pObj)
if(pOL && !pObj->Is3DObj())
{
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -631,7 +631,7 @@ basegfx::B2DPolyPolygon SdrEditView::ImpGetPolyPolygon1(const SdrObject* pObj, b
if(pOL)
{
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -668,7 +668,7 @@ basegfx::B2DPolyPolygon SdrEditView::ImpGetPolyPolygon(const SdrObject* pObj, bo
if(pOL && !pObj->Is3DObj())
{
basegfx::B2DPolyPolygon aRetval;
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -1034,7 +1034,7 @@ void SdrEditView::MergeMarkedObjects(SdrMergeMode eMode)
// #i76891# use single iteration from SJ here which works on SdrObjects and takes
// groups into account by itself
- SdrObjListIter aIter(*pObj, IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pObj, SdrIterMode::DeepWithGroups);
while(aIter.IsMore())
{
@@ -1437,7 +1437,7 @@ bool SdrEditView::ImpCanDismantle(const SdrObject* pObj, bool bMakeLines)
if(pOL)
{
// group object -- check all members if they're PathObjs
- SdrObjListIter aIter(*pOL, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pOL, SdrIterMode::DeepNoGroups);
while(aIter.IsMore() && !bOtherObjs)
{
@@ -1685,7 +1685,7 @@ void SdrEditView::DismantleMarkedObjects(bool bMakeLines)
size_t nPos=nPos0+1;
SdrObjList* pSubList=pObj->GetSubList();
if (pSubList!=nullptr && !pObj->Is3DObj()) {
- SdrObjListIter aIter(*pSubList,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pSubList,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
const SdrObject* pObj1=aIter.Next();
ImpDismantleOneObject(pObj1,*pOL,nPos,pPV,bMakeLines);
@@ -1974,7 +1974,7 @@ void SdrEditView::ImpConvertTo(bool bPath, bool bLineToArea)
SdrPageView* pPV=pM->GetPageView();
if (pObj->IsGroupObject() && !pObj->Is3DObj()) {
SdrObject* pGrp=pObj;
- SdrObjListIter aIter(*pGrp,IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pGrp,SdrIterMode::DeepNoGroups);
while (aIter.IsMore()) {
pObj=aIter.Next();
ImpConvertOneObj(pObj,bPath,bLineToArea);
diff --git a/svx/source/svdraw/svdfmtf.cxx b/svx/source/svdraw/svdfmtf.cxx
index f1bdb80be7ef..42027a423a4f 100644
--- a/svx/source/svdraw/svdfmtf.cxx
+++ b/svx/source/svdraw/svdfmtf.cxx
@@ -510,7 +510,7 @@ void ImpSdrGDIMetaFileImport::InsertObj(SdrObject* pObj, bool bScale)
{
// recursively add created conversion; per definition this shall not
// contain further SdrTextObjs. Visit only non-group objects
- SdrObjListIter aIter(*pConverted, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*pConverted, SdrIterMode::DeepNoGroups);
// work with clones; the created conversion may contain group objects
// and when working with the original objects the loop itself could
@@ -519,7 +519,7 @@ void ImpSdrGDIMetaFileImport::InsertObj(SdrObject* pObj, bool bScale)
while(aIter.IsMore())
{
SdrObject* pCandidate = aIter.Next();
- OSL_ENSURE(pCandidate && dynamic_cast< SdrObjGroup* >(pCandidate) == nullptr, "SdrObjListIter with IM_DEEPNOGROUPS error (!)");
+ OSL_ENSURE(pCandidate && dynamic_cast< SdrObjGroup* >(pCandidate) == nullptr, "SdrObjListIter with SdrIterMode::DeepNoGroups error (!)");
SdrObject* pNewClone = pCandidate->Clone();
if(pNewClone)
diff --git a/svx/source/svdraw/svditer.cxx b/svx/source/svdraw/svditer.cxx
index 3ed440278c17..a8e56773ff8c 100644
--- a/svx/source/svdraw/svditer.cxx
+++ b/svx/source/svdraw/svditer.cxx
@@ -86,10 +86,10 @@ void SdrObjListIter::ImpProcessObj(SdrObject* pObj, SdrIterMode eMode, bool bUse
if( bIsGroup && dynamic_cast<const E3dObject* >(pObj) != nullptr && dynamic_cast<const E3dScene* >(pObj) == nullptr)
bIsGroup = false;
- if( !bIsGroup || (eMode != IM_DEEPNOGROUPS) )
+ if( !bIsGroup || (eMode != SdrIterMode::DeepNoGroups) )
maObjList.push_back(pObj);
- if( bIsGroup && (eMode != IM_FLAT) )
+ if( bIsGroup && (eMode != SdrIterMode::Flat) )
ImpProcessObjectList( *pObj->GetSubList(), eMode, bUseZOrder );
}
diff --git a/svx/source/svdraw/svdpage.cxx b/svx/source/svdraw/svdpage.cxx
index 141f2f7b6fff..59def840f466 100644
--- a/svx/source/svdraw/svdpage.cxx
+++ b/svx/source/svdraw/svdpage.cxx
@@ -645,7 +645,7 @@ void SdrObjList::ReformatAllTextObjects()
void SdrObjList::ReformatAllEdgeObjects()
{
// #i120437# go over whole hierarchy, not only over object level null (seen from grouping)
- SdrObjListIter aIter(*this, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*this, SdrIterMode::DeepNoGroups);
while(aIter.IsMore())
{
@@ -1641,7 +1641,7 @@ void SdrPage::SetInserted( bool bIns )
mbInserted = bIns;
// #i120437# go over whole hierarchy, not only over object level null (seen from grouping)
- SdrObjListIter aIter(*this, IM_DEEPNOGROUPS);
+ SdrObjListIter aIter(*this, SdrIterMode::DeepNoGroups);
while ( aIter.IsMore() )
{
diff --git a/svx/source/unodraw/unoshap3.cxx b/svx/source/unodraw/unoshap3.cxx
index fe6505d655b4..d3ab906ea951 100644
--- a/svx/source/unodraw/unoshap3.cxx
+++ b/svx/source/unodraw/unoshap3.cxx
@@ -322,7 +322,7 @@ bool Svx3DSceneObject::setPropertyValueImpl( const OUString& rName, const SfxIte
aSceneTAR.maRect = pScene->GetSnapRect();
// rescue object transformations
- SdrObjListIter aIter(*pScene->GetSubList(), IM_DEEPWITHGROUPS);
+ SdrObjListIter aIter(*pScene->GetSubList(), SdrIterMode::DeepWithGroups);
std::vector<basegfx::B3DHomMatrix*> aObjTrans;
while(aIter.IsMore())
{
diff --git a/svx/source/svdraw/svdsnpv.cxx b/svx/source/svdraw/svdsnpv.cxx
index c7b34b47e510..e2259d4aeafb 100644
--- a/svx/source/svdraw/svdsnpv.cxx
+++ b/svx/source/svdraw/svdsnpv.cxx
@@ -331,8 +331,8 @@ SdrSnap SdrSnapView::SnapPos(Point& rPnt, const SdrPageView* pPV) const
sal_uIntPtr nMaxPointSnapCount=200;
sal_uIntPtr nMaxFrameSnapCount=200;
- // go back to IM_DEEPNOGROUPS runthrough for snap to object comparisons
- SdrObjListIter aIter(*pPV->GetPage(),IM_DEEPNOGROUPS,true);
+ // go back to SdrIterMode::DeepNoGroups runthrough for snap to object comparisons
+ SdrObjListIter aIter(*pPV->GetPage(),SdrIterMode::DeepNoGroups,true);
while (aIter.IsMore() && (nMaxPointSnapCount>0 || nMaxFrameSnapCount>0)) {
SdrObject* pO=aIter.Next();